Index: PRESUBMIT.py |
diff --git a/PRESUBMIT.py b/PRESUBMIT.py |
index be2626963a03ac0e1ab5604c6e82e677886796fc..3a1b52eb0ce40260c4056ec1c69b6e1ae59fb355 100755 |
--- a/PRESUBMIT.py |
+++ b/PRESUBMIT.py |
@@ -29,31 +29,34 @@ CPPLINT_DIRS = [ |
# 3. Deprecation is announced to discuss-webrtc@googlegroups.com and |
# webrtc-users@google.com (internal list). |
# 4. (later) The deprecated APIs are removed. |
-# Directories marked as DEPRECATED should not be used. They're only present in |
-# the list to support legacy downstream code. |
NATIVE_API_DIRS = ( |
'talk/app/webrtc', |
the sun
2015/12/10 10:56:57
Note that until there is an include/ dir under tal
|
'webrtc', |
- 'webrtc/base', # DEPRECATED. |
- 'webrtc/common_audio/include', # DEPRECATED. |
'webrtc/modules/audio_coding/include', |
the sun
2015/12/10 10:02:20
Move to LEGACY:
webrtc/modules/audio_coding/includ
stefan-webrtc
2015/12/10 10:14:32
No, I'm OK with that. We don't want new projects t
pbos-webrtc
2015/12/10 10:20:01
I think all of video_coding should also go under l
the sun
2015/12/10 10:56:57
Ah, I thought that was required to feed codec inst
|
- 'webrtc/modules/audio_conference_mixer/include', # DEPRECATED. |
'webrtc/modules/audio_device/include', |
'webrtc/modules/audio_processing/include', |
'webrtc/modules/bitrate_controller/include', |
'webrtc/modules/include', |
'webrtc/modules/remote_bitrate_estimator/include', |
'webrtc/modules/rtp_rtcp/include', |
- 'webrtc/modules/rtp_rtcp/source', # DEPRECATED. |
'webrtc/modules/utility/include', |
'webrtc/modules/video_coding/codecs/h264/include', |
'webrtc/modules/video_coding/codecs/i420/include', |
'webrtc/modules/video_coding/codecs/vp8/include', |
'webrtc/modules/video_coding/codecs/vp9/include', |
'webrtc/modules/video_coding/include', |
- 'webrtc/system_wrappers/include', # DEPRECATED. |
'webrtc/voice_engine/include', |
) |
+# These directories should not be used but are maintained only to avoid breaking |
+# some legacy downstream code. |
+LEGACY_API_DIRS = ( |
+ 'webrtc/base', |
+ 'webrtc/common_audio/include', |
+ 'webrtc/modules/audio_conference_mixer/include', |
+ 'webrtc/modules/rtp_rtcp/source', |
+ 'webrtc/system_wrappers/include', |
+) |
+API_DIRS = NATIVE_API_DIRS[:] + LEGACY_API_DIRS[:] |
def _VerifyNativeApiHeadersListIsValid(input_api, output_api): |
@@ -61,7 +64,7 @@ def _VerifyNativeApiHeadersListIsValid(input_api, output_api): |
non_existing_paths = [] |
native_api_full_paths = [ |
input_api.os_path.join(input_api.PresubmitLocalPath(), |
*path.split('/')) for path in NATIVE_API_DIRS] |
for path in native_api_full_paths: |
if not os.path.isdir(path): |
non_existing_paths.append(path) |
@@ -79,7 +82,7 @@ def _CheckNativeApiHeaderChanges(input_api, output_api): |
files = [] |
for f in input_api.AffectedSourceFiles(input_api.FilterSourceFile): |
if f.LocalPath().endswith('.h'): |
- for path in NATIVE_API_DIRS: |
+ for path in API_DIRS: |
if os.path.dirname(f.LocalPath()) == path: |
files.append(f) |
@@ -61,7 +64,7 @@ def _VerifyNativeApiHeadersListIsValid(input_api, output_api): |
native_api_full_paths = [ |
input_api.os_path.join(input_api.PresubmitLocalPath(), |
- *path.split('/')) for path in NATIVE_API_DIRS] |
+ *path.split('/')) for path in API_DIRS] |
for path in native_api_full_paths: |
if not os.path.isdir(path): |